@@ -44,14 +44,20 @@ class ListInsightsRequest(proto.Message):
             Required. The container resource on which to execute the
             request. Acceptable formats:
 
-            1.
+            -  ``projects/[PROJECT_NUMBER]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]``
 
-            "projects/[PROJECT_NUMBER]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]",
+            -  ``projects/[PROJECT_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]``
+
+            -  ``billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]``
+
+            -  ``folders/[FOLDER_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]``
+
+            -  ``organizations/[ORGANIZATION_ID]/locations/[LOCATION]/insightTypes/[INSIGHT_TYPE_ID]``
 
             LOCATION here refers to GCP Locations:
             https://cloud.google.com/about/locations/ INSIGHT_TYPE_ID
             refers to supported insight types:
-            https://cloud.google.com/recommender/docs/insights/insight-types.)
+            https://cloud.google.com/recommender/docs/insights/insight-types.
         page_size (int):
             Optional. The maximum number of results to
             return from this request.  Non-positive values
@@ -65,8 +71,26 @@ class ListInsightsRequest(proto.Message):
             identical to those in the previous call.
         filter (str):
             Optional. Filter expression to restrict the insights
-            returned. Supported filter fields: state Eg:
-            \`state:"DISMISSED" or state:"ACTIVE".
+            returned. Supported filter fields:
+
+            -  ``stateInfo.state``
+
+            -  ``insightSubtype``
+
+            -  ``severity``
+
+            Examples:
+
+            -  ``stateInfo.state = ACTIVE OR stateInfo.state = DISMISSED``
+
+            -  ``insightSubtype = PERMISSIONS_USAGE``
+
+            -  ``severity = CRITICAL OR severity = HIGH``
+
+            -  ``stateInfo.state = ACTIVE AND (severity = CRITICAL OR severity = HIGH)``
+
+            (These expressions are based on the filter language
+            described at https://google.aip.dev/160)
     """
 
     parent = proto.Field(proto.STRING, number=1,)
@@ -133,9 +157,15 @@ class ListRecommendationsRequest(proto.Message):
             Required. The container resource on which to execute the
             request. Acceptable formats:
 
-            1.
+            -  ``projects/[PROJECT_NUMBER]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]``
 
-            "projects/[PROJECT_NUMBER]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]",
+            -  ``projects/[PROJECT_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]``
+
+            -  ``billingAccounts/[BILLING_ACCOUNT_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]``
+
+            -  ``folders/[FOLDER_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]``
+
+            -  ``organizations/[ORGANIZATION_ID]/locations/[LOCATION]/recommenders/[RECOMMENDER_ID]``
 
             LOCATION here refers to GCP Locations:
             https://cloud.google.com/about/locations/ RECOMMENDER_ID
@@ -154,8 +184,26 @@ class ListRecommendationsRequest(proto.Message):
             identical to those in the previous call.
         filter (str):
             Filter expression to restrict the recommendations returned.
-            Supported filter fields: state_info.state Eg:
-            \`state_info.state:"DISMISSED" or state_info.state:"FAILED".
+            Supported filter fields:
+
+            -  ``state_info.state``
+
+            -  ``recommenderSubtype``
+
+            -  ``priority``
+
+            Examples:
+
+            -  ``stateInfo.state = ACTIVE OR stateInfo.state = DISMISSED``
+
+            -  ``recommenderSubtype = REMOVE_ROLE OR recommenderSubtype = REPLACE_ROLE``
+
+            -  ``priority = P1 OR priority = P2``
+
+            -  ``stateInfo.state = ACTIVE AND (priority = P1 OR priority = P2)``
+
+            (These expressions are based on the filter language
+            described at https://google.aip.dev/160)
     """
 
     parent = proto.Field(proto.STRING, number=1,)
